'use strict';

const yargs = require('yargs');
const cosmiconfig = require('cosmiconfig');
const packageName = require('../../package.json').name;

const getCliOptions = () => {
    const cliOptions = yargs
        .options('f', {
            type: 'string',
            alias: 'files',
            describe: '待处理的文件扩展名，多个扩展名以英文逗号分隔',
        })
        .options('d', {
            type: 'string',
            alias: 'dirs',
            describe: '待处理的入口文件目录，多个目录以英文逗号分隔',
        })
        .options('i', {
            type: 'string',
            alias: 'ignore',
            describe: '忽略的文件目录，多个目录以英文逗号分隔',
        })
        .options('l', {
            type: 'string',
            alias: 'langs',
            describe: '生成的语言文件，多个语言以英文逗号分隔',
        })
        .options('v', {
            boolean: true,
            alias: 'version',
        })
        .usage('Usage: translateman [options]')
        .example('translateman -f jsx', 'translate jsx file')
        .epilog('copyright 2018')
        .alias('h', 'help')
        .help('h').argv;

    return cliOptions;
};

const getFileOptions = () => {
    const configExplorer = cosmiconfig(packageName);
    const fileOptions = configExplorer.searchSync().config;
    return fileOptions;
};

const getOptions = () => {
    const cliOptions = getCliOptions();
    const fileOptions = getFileOptions();
    const options = {};
    if (cliOptions.f && typeof cliOptions.f === 'string') {
        options.files = cliOptions.f.split(',');
    } else {
        options.files = fileOptions.files;
    }
    if (cliOptions.d && typeof cliOptions.d === 'string') {
        options.dirs = cliOptions.d.split(',');
    } else {
        options.dirs = fileOptions.dirs;
    }
    if (cliOptions.i && typeof cliOptions.i === 'string') {
        options.ignore = cliOptions.i.split(',');
    } else {
        options.ignore = fileOptions.ignore;
    }
    if (cliOptions.l && typeof cliOptions.l === 'string') {
        options.langs = cliOptions.l.split(',');
    } else {
        options.langs = fileOptions.langs;
    }
    options.version = cliOptions.v;
    options.help = cliOptions.h;
    return options;
};

module.exports = {
    getCliOptions,
    getFileOptions,
    getOptions,
};
