'use strict';

const parser = require('./parser');
const transformer = require('./transformer');
const file = require('../util/file');
const logger = require('../util/logger');
const formatter = require('../util/formatter');
const version = require('../../package.json').version;

const { locale_file_path, locale_zh_hans_cn } = require('../config/common');

const getChinese = file => {
  const chineseFiles = [];
  file.map(path => {
    const fileSource = file.readFile(file);
    const chineseNodes = parser.parseChineseNode(fileSource);
    chineseNodes.forEach(item => {
      item.text_pinyin = parser.parseChinesePinyin(item.text);
    });
    chineseFiles.push({
      file: path,
      chinese: chineseNodes,
    });
  });
  return chineseFiles;
};

const generateLocaleFiles = (chineseNodes, langs) => {
  // 确保多语言目录
  file.ensurePath(locale_file_path);
  // 中文语言配置文件
  const localeChineseFile = `${locale_file_path}/${locale_zh_hans_cn}.json`;
  // 已存在的语言配置数据
  const LocaleChineseNodes = file.readJsonFile(localeChineseFile);
  // 与配置语言合并后的数据
  chineseNodes = formatter.duplicateChineseNodesWithFile(chineseNodes, LocaleChineseNodes);
  langs.forEach(lang => {
    const langPath = `${locale_file_path}/${lang}.json`;
    let localeLangNodes = file.readJsonFile(langPath);
    localeLangNodes = formatter.generateNewLocaleFile(chineseNodes, localeLangNodes);
    file.writeJsonFile(langPath, localeLangNodes);
  });

  return chineseNodes;
};

const transformChineseFile = chineseNodes => {
  chineseNodes &&
    chineseNodes.forEach(node => {
      transformer.transformFile(node);
    });
};

const execute = options => {
  const files = file.readFilePaths(options);
  if (files && files.length) {
    // 原始的中文数据，未去重
    let chineseNodes = getChinese(files);
    // 中文数据配置键去重
    chineseNodes = formatter.duplicateChineseNodes(chineseNodes);
    // 与本地语言配置文件合并后的数据
    chineseNodes = generateLocaleFiles(chineseNodes, [locale_zh_hans_cn, ...options.langs]);
    // 替换代码文件中的中文编码
    transformChineseFile(chineseNodes);
  } else {
    logger.error('未获取到任何文件');
  }
};

module.exports = {
  version,
  execute,
};