'use strict';

const fs = require('fs');
const path = require('path');
const globby = require('globby');
const jsonfile = require('jsonfile');
const logger = require('./logger');
const formatter = require('./formatter');

const formatFilePath = filePath => {
  return `${process.cwd()}${path.seq}${filePath}`;
};

const ensurePath = filePath => {
  let pathName = `${formatFilePath(filePath)}`;
  if (!fs.existsSync(pathName)) {
    fs.mkdirSync(pathName);
  }
};

const readFile = filePath => {
  try {
    return fs.readFileSync(`${formatFilePath(filePath)}`, {
      encoding: 'utf8',
    });
  } catch (e) {
    throw e;
  }
};

const writeFile = (filePath, fileContent) => {
  try {
    return fs.writeFileSync(`${formatFilePath(filePath)}`, fileContent);
  } catch (e) {
    throw e;
  }
};

const readJsonFile = filePath => {
  let jsonContent = null;
  try {
    jsonContent = JSON.parse(
      fs.readFileSync(`${formatFilePath(filePath)}`, {
        encoding: 'utf8',
      })
    )
  } catch (e) {

  }
  return jsonContent;
};

const readFilePaths = options => {
  let { dirs, ignore, files } = formatter.formatOptions(options);
  let filePaths = [];
  try {
    filePaths = globby.sync(dirs, {
      deep: true,
      onlyFiles: true,
      ignore,
      expandDirectories: {
        files: files,
      },
    });
  } catch (e) {
    logger.error(`globby file handle error: \n${e.message}`);
    process.exitCode = 2;
  }
  return filePaths;
};

const writeJsonFile = (file, json) => {
  jsonfile.writeFile(
    file,
    json,
    {
      spaces: 2,
    },
    function (err) {
      err && logger.error(err);
    }
  )
};

module.exports = {
  ensurePath,
  readFile,
  readJsonFile,
  readFilePaths,
  writeFile,
  writeJsonFile,
};

