'use strict';

const formatDirs = dirs => {
  dirs.concat(['!**/node_modules/**', '!./node_modules/**']);
  return dirs;
};

const formatIgnories = ignores => {
  const formatedIgnore = [];
  ignores.forEach(ignore => {
    formatedIgnore.push(`**/${ignore}/**`);
  });
  return formatedIgnore;
};

const formatFiles = files => {
  const formatedFiles = [];
  files.forEach(file => {
    formatedFiles.push(`*.${file}`);
  });
  return formatedFiles;
};

const formatOptions = options => {
  const { dirs, ignore, files } = options;
  return {
    dirs: formatDirs(dirs),
    ignore: formatIgnories(ignore),
    files: formatFiles(files),
  };
};

const duplicateChineseNodes = nodes => {
  let texts = [];
  let textPinyins = [];
  const generatePinyin = (text, textPinyin, postfix, textPinyinOrigin = textPinyin) => {
    if (textPinyins.includes(textPinyin) && !texts.includes(text)) {
      postfix++;
      textPinyin = textPinyinOrigin + '_' + postfix;
      return generatePinyin(text, textPinyin, postfix, textPinyinOrigin);
    }
    return textPinyin;
  };

  nodes.map(node => {
    node.chinese &&
    node.chinese.map(chinese => {
      let chineseText = chinese.text;
      let chineseTextPinyin = chinese.text_pinyin;

      chineseTextPinyin = generatePinyin(chineseText, chineseTextPinyin, 0);
      chinese.text_pinyin = chineseTextPinyin;

      texts.push(chineseText);
      textPinyins.push(chineseTextPinyin);
    });
  });

  return nodes;
};

const duplicateChineseNodesWithFile = (nodes, fileNodes) => {
  if (fileNodes && Object.keys(fileNodes).length > 0) {
    const getNodeKey = nodeText => {
      let nodeKey = null;
      for (let key in fileNodes) {
        if (fileNodes[key] === nodeText) {
          nodeKey = key;
          break;
        }
      }
      return nodeKey;
    };

    const generateNodeKey = (textPinyin, postfix, textPinyinOrigin = textPinyin) => {
      if (fileNodes[textPinyin]) {
        postfix++;
        textPinyin = textPinyinOrigin + '_' + postfix;
        return generateNodeKey(textPinyin, postfix, textPinyinOrigin);
      }
      return textPinyin;
    };

    nodes.map(node => {
      node.chinese &&
      node.chinese.map(chinese => {
        let chineseText = chinese.text;
        let nodeKey = getNodeKey(chineseText);
        if (nodeKey) {
          chinese.text_pinyin = nodeKey;
        } else {
          let chineseTextPinyin = chinese.text_pinyin;
          chineseTextPinyin = generateNodeKey(chineseTextPinyin, 0);
          chinese.text_pinyin = chineseTextPinyin;
        }
      });
    });
  }

  return nodes;
};

const generateNewLocaleFile = (chineseNodes, localeNodes) => {
  localeNodes = localeNodes || {};
  chineseNodes.map(node => {
    node.chinese &&
    node.chinese.map(chinese => {
      const chineseText = chinese.text;
      const chineseTextPinyin = chinese.text_pinyin;
      if (!localeNodes[chineseTextPinyin]) {
        localeNodes[chineseTextPinyin] = chineseText;
      }
    });
  });
  return localeNodes;
};

module.exports = {
  formatOptions,
  formatDirs,
  formatIgnories,
  formatFiles,
  duplicateChineseNodes,
  duplicateChineseNodesWithFile,
  generateNewLocaleFile,
};
