'use strict';
const chalk = require('chalk');

const createLogger = () => {
  return {
    warn: createLogFunc('warn', 'yellow'),
    error: createLogFunc('error', 'red'),
    debug: createLogFunc('debug', 'blue'),
    log: createLogFunc('log', 'green'),
  };

  function createLogFunc(loggerName, color) {
    const prefix = color ? `[${chalk[color](loggerName)}]` : '';
    return function (message, opts) {
      opts = Object.assign({ newline: true }, opts);
      const stream = process[loggerName === 'log' ? 'stdout' : 'stderr'];
      stream.write(message.replace(/^/gm, prefix) + (opts.newline ? '\n' : ''));
    }
  }
};

const logger = createLogger();

const json = json => {
  logger.log(JSON.stringify(json, null, 2));
};

const write = (text, color = 'gray') => {
  const writeContent = chalk[color](text);
  console.info(writeContent);
};

module.exports = {
  ...logger,
  json,
  write,
};